@@ -16,11 +16,14 @@ import base64
 import errno
 import os
 import shelve
-import uuid
 
-from Crypto.PublicKey import RSA
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.primitives import serialization
+
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import uuidutils
 
 from solum.api.handlers import assembly_handler
 from solum.api.handlers import handler
@@ -96,10 +99,10 @@ class PlanHandler(handler.Handler):
         db_obj = objects.registry.Plan()
         if 'name' in data:
             db_obj.name = data['name']
-        db_obj.uuid = str(uuid.uuid4())
+        db_obj.uuid = uuidutils.generate_uuid()
         db_obj.user_id = self.context.user
         db_obj.project_id = self.context.tenant
-        db_obj.trigger_id = str(uuid.uuid4())
+        db_obj.trigger_id = uuidutils.generate_uuid()
 
         # create a delegation trust_id\token, if required
         db_obj.trust_id = keystone_utils.create_delegation_token(self.context)
@@ -129,14 +132,26 @@ class PlanHandler(handler.Handler):
                     ('private' not in artifact['content']) or
                     (not artifact['content']['private'])):
                 continue
-            new_key = RSA.generate(2048)
-            public_key = new_key.publickey().exportKey("OpenSSH")
-            private_key = new_key.exportKey("PEM")
+            new_key = rsa.generate_private_key(
+                public_exponent=65537,
+                key_size=2048,
+                backend=default_backend()
+            )
+            public_key = new_key.public_key().public_bytes(
+                serialization.Encoding.OpenSSH,
+                serialization.PublicFormat.OpenSSH
+            )
+            private_key = new_key.private_bytes(
+                encoding=serialization.Encoding.PEM,
+                format=serialization.PrivateFormat.TraditionalOpenSSL,
+                encryption_algorithm=serialization.NoEncryption()
+            )
             artifact['content']['public_key'] = public_key
             deploy_keys.append({'source_url': artifact['content']['href'],
                                 'private_key': private_key})
         if deploy_keys:
-            encoded_payload = base64.b64encode(bytes(str(deploy_keys)))
+            encoded_payload = base64.b64encode(
+                bytes(str(deploy_keys).encode('utf-8')))
             repo_deploy_keys = ''
             if sys_param_store == 'database':
                 repo_deploy_keys = encoded_payload
