@@ -12,8 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_log import log as logging
-
 import json
 import os
 
@@ -25,9 +23,6 @@ from solum.common import solum_swiftclient
 from solum import objects
 
 
-LOG = logging.getLogger(__name__)
-
-
 class UserlogHandler(handler.Handler):
 
     def get_all(self):
