@@ -15,17 +15,23 @@
 
 from oslo_config import cfg
 from oslo_middleware import cors
+from oslo_policy import opts
 
 
 def set_config_defaults():
     """This method updates all configuration default values."""
     set_cors_middleware_defaults()
 
+    # TODO(gmann): Remove setting the default value of config policy_file
+    # once oslo_policy change the default value to 'policy.yaml'.
+    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+    opts.set_defaults(cfg.CONF, 'policy.yaml')
+
 
 def set_cors_middleware_defaults():
     """Update default configuration options for oslo.middleware."""
     # CORS Defaults
-    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
+    # TODO(krotscheck): Update with https://review.opendev.org/#/c/285368/
     cfg.set_defaults(cors.CORS_OPTS,
                      allow_headers=['X-Auth-Token',
                                     'X-Openstack-Request-Id',
